@@ -47,7 +47,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <KRun>
 #include <KXMLGUIClient>
 #include <KUrlMimeData>
-#include <KFileItemActions>
 #include <KFileItemListProperties>
 #include <KIO/OpenFileManagerWindowJob>
 
@@ -359,7 +358,7 @@ void FileOpsContextManagerItem::rename()
         QModelIndex index = mThumbnailView->currentIndex();
         mThumbnailView->edit(index);
     } else {
-        FileOperations::rename(urlList().first(), mGroup, contextManager());
+        FileOperations::rename(urlList().constFirst(), mGroup, contextManager());
         contextManager()->slotSelectionChanged();
     }
 }
