@@ -709,14 +709,11 @@ struct MainWindow::Private
             break;
         case BrowseMainPageId:
             return GwenviewConfig::sideBarVisibleBrowseMode();
-            break;
         case ViewMainPageId:
             return q->isFullScreen()
                 ? GwenviewConfig::sideBarVisibleViewModeFullScreen()
                 : GwenviewConfig::sideBarVisibleViewMode();
-            break;
         }
-
         return false;
     }
 
@@ -745,14 +742,11 @@ struct MainWindow::Private
             break;
         case BrowseMainPageId:
             return GwenviewConfig::statusBarVisibleBrowseMode();
-            break;
         case ViewMainPageId:
             return q->isFullScreen()
                 ? GwenviewConfig::statusBarVisibleViewModeFullScreen()
                 : GwenviewConfig::statusBarVisibleViewMode();
-            break;
         }
-
         return false;
     }
 
@@ -866,9 +860,21 @@ MainWindow::MainWindow()
                                           d->mGoToPreviousAction, d->mGoToNextAction, this);
 #endif
 
+#ifdef GWENVIEW_SEMANTICINFO_BACKEND_NONE
+    auto* ratingMenu = static_cast<QMenu*>(guiFactory()->container("rating", this));
+    if (ratingMenu) {
+        ratingMenu->menuAction()->setVisible(false);
+    }
+#endif
+
 #ifdef KIPI_FOUND
     d->mKIPIInterface = new KIPIInterface(this);
     d->mKIPIExportAction->setKIPIInterface(d->mKIPIInterface);
+#else
+    auto* pluginsMenu = static_cast<QMenu*>(guiFactory()->container("plugins", this));
+    if (pluginsMenu) {
+        pluginsMenu->menuAction()->setVisible(false);
+    }
 #endif
     setAutoSaveSettings();
 #ifdef Q_OS_OSX
@@ -1280,7 +1286,6 @@ void MainWindow::goToUrl(const QUrl &url)
     }
     QUrl dirUrl = url;
     dirUrl = dirUrl.adjusted(QUrl::RemoveFilename);
-    dirUrl.setPath(dirUrl.path() + "");
     if (dirUrl != d->mContextManager->currentDirUrl()) {
         d->mContextManager->setCurrentDirUrl(dirUrl);
         d->mGvCore->addUrlToRecentFolders(dirUrl);
@@ -1521,6 +1526,12 @@ void MainWindow::configureShortcuts()
 void MainWindow::toggleMenuBar()
 {
     if (!d->mFullScreenAction->isChecked()) {
+        if (!d->mShowMenuBarAction->isChecked()) {
+            const QString accel = d->mShowMenuBarAction->shortcut().toString();
+            KMessageBox::information(this, i18n("This will hide the menu bar completely."
+                                                " You can show it again by typing %1.", accel),
+                                     i18n("Hide menu bar"), QLatin1String("HideMenuBarWarning"));
+        }
         menuBar()->setVisible(d->mShowMenuBarAction->isChecked());
     }
 }
