@@ -82,7 +82,7 @@ public:
      * install scene event filters.
      */
     explicit DocumentView(QGraphicsScene* scene);
-    ~DocumentView() Q_DECL_OVERRIDE;
+    ~DocumentView() override;
 
     Document::Ptr document() const;
 
@@ -129,7 +129,7 @@ public:
     void fadeOut();
     void fakeFadeOut();
 
-    void setGeometry(const QRectF& rect) Q_DECL_OVERRIDE;
+    void setGeometry(const QRectF& rect) override;
 
     int sortKey() const;
     void setSortKey(int sortKey);
@@ -201,13 +201,13 @@ Q_SIGNALS:
     void isAnimatedChanged();
 
 protected:
-    void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = nullptr) Q_DECL_OVERRIDE;
+    void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = nullptr) override;
 
-    void resizeEvent(QGraphicsSceneResizeEvent* event) Q_DECL_OVERRIDE;
-    void mousePressEvent(QGraphicsSceneMouseEvent* event) Q_DECL_OVERRIDE;
-    void wheelEvent(QGraphicsSceneWheelEvent* event) Q_DECL_OVERRIDE;
-    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event) Q_DECL_OVERRIDE;
-    bool sceneEventFilter(QGraphicsItem*, QEvent*) Q_DECL_OVERRIDE;
+    void resizeEvent(QGraphicsSceneResizeEvent* event) override;
+    void mousePressEvent(QGraphicsSceneMouseEvent* event) override;
+    void wheelEvent(QGraphicsSceneWheelEvent* event) override;
+    void contextMenuEvent(QGraphicsSceneContextMenuEvent* event) override;
+    bool sceneEventFilter(QGraphicsItem*, QEvent*) override;
     void dragEnterEvent(QGraphicsSceneDragDropEvent* event) override;
     void dropEvent(QGraphicsSceneDragDropEvent* event) override;
 
