@@ -26,7 +26,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // KDE
 #include <QDebug>
 #include <QStandardPaths>
-#include <QStandardPaths>
 #include <qtest.h>
 #include <kio_version.h>
 
@@ -109,10 +108,7 @@ void PlaceTreeModelTest::init()
     Q_ASSERT(bookmarkOpened);
     Q_UNUSED(bookmarkOpened);
 
-    QString xml = QString(BOOKMARKS_XML)
-                  .arg(mUrl1.url())
-                  .arg(mUrl2.url())
-                  ;
+    QString xml = QString(BOOKMARKS_XML).arg(mUrl1.url(), mUrl2.url());
     bookmark.write(xml.toUtf8());
 
 #ifdef KEEP_TEMP_DIR
@@ -127,10 +123,8 @@ void PlaceTreeModelTest::testListPlaces()
 
 #if KIO_VERSION >= QT_VERSION_CHECK(5, 45, 0)
     QCOMPARE(model.rowCount(), 8);
-#elif KIO_VERSION >= QT_VERSION_CHECK(5, 41, 0)
-    QCOMPARE(model.rowCount(), 10);
 #else
-    QCOMPARE(model.rowCount(), 2);
+    QCOMPARE(model.rowCount(), 10);
 #endif
 
     QModelIndex index;
