@@ -6,8 +6,6 @@
 #include <QImageReader>
 #include <QTime>
 
-#include <lib/imageformats/imageformats.h>
-
 const int ITERATIONS = 2;
 const QSize SCALED_SIZE(1280, 800);
 
@@ -45,7 +43,7 @@ int main(int argc, char** argv)
 
     QFile file(fileName);
     if (!file.open(QIODevice::ReadOnly)) {
-        qDebug() << QString("Could not open '%1'").arg(fileName);
+        qDebug() << QStringLiteral("Could not open '%1'").arg(fileName);
         return 2;
     }
     QByteArray data = file.readAll();
@@ -53,9 +51,6 @@ int main(int argc, char** argv)
 
     qDebug() << "Using Qt loader";
     bench(&buffer, "qt.png");
-    Gwenview::ImageFormats::registerPlugins();
-    qDebug() << "Using Gwenview loader";
-    bench(&buffer, "gv.png");
 
     return 0;
 }
